
<table style="border: 1px solid transparent">
  <tr>
    <td>
<a href="https://talkytrader.github.io/wiki/"><img src="https://img.shields.io/badge/Wiki-%23000000.svg?style=for-the-badge&logo=wikipedia&logoColor=white"></a>
<a href="https://github.com/mraniki/tt/"><img src="https://img.shields.io/badge/github-%23000000.svg?style=for-the-badge&logo=github&logoColor=white"></a>
<a href="https://hub.docker.com/r/mraniki/tt"><img src="https://img.shields.io/docker/pulls/mraniki/tt?style=for-the-badge"></a>
<br>
    </td>
    <td align="center"><img width="200" alt="Logo" src="/docs/_static/logo-full.png"></td>
  </tr>
  <tr>
    <td>
      <a href="https://pypi.org/project/headlinehunt/"><img src="https://img.shields.io/pypi/v/headlinehunt?style=for-the-badge&logo=PyPI&logoColor=white"></a><br>
      <a href="https://pypi.org/project/headlinehunt/"><img src="https://img.shields.io/pypi/dm/headlinehunt?style=for-the-badge&logo=PyPI&logoColor=white&label=pypi&labelColor=grey"></a><br>
      <a href="https://github.com/mraniki/headlinehunt/"><img src="https://img.shields.io/github/actions/workflow/status/mraniki/headlinehunt/%F0%9F%91%B7Flow.yml?style=for-the-badge&logo=GitHub&logoColor=white"></a><br>
   <a href="https://talky.readthedocs.io/"><img src="https://readthedocs.org/projects/headlinehunt/badge/?version=latest&style=for-the-badge"></a><br>
   <a href="https://codebeat.co/projects/github-com-mraniki-xxxxxxx-main"><img src="https://codebeat.co/badges/headlinehunt"/></a><br>
   <a href="https://codecov.io/gh/mraniki/xxxxxxx"> <img src="https://codecov.io/gh/mraniki/headlinehunt/branch/main/graph/badge.svg?token=xxxxxxx"/></a><br>
    </td>
    <td align="left"> 
      Get your news<br>
       xxxxxxx.
    </td>
     
  </tr>
</table>

<h5>How to use it</h5>
<pre>
<code>
    
    
</code>
</pre>


<h5>Documentation</h5>
<a href="https://talky.readthedocs.io/projects/headlinehunt/en/latest/"><img src="https://img.shields.io/badge/Documentation-000000?style=for-the-badge&logo=readthedocs&logoColor=white"></a><br>
